# coding=utf-8
"""
Simulador Integral de Cadenas Productivas (SICP)

Copyleft (@) 2015 CENDITEL nodo Mérida - https://miv.cenditel.gob.ve/simulacion/
"""
# # @package usuario.models
#
# Modelo de datos para el registro y autenticación de usuarios con privilegios para acceder al sistema
# @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
# @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) nodo Mérida - Venezuela
# @copyright GNU/GPLv2
# @date 04-05-2015
# @version 3.0.0

## Muestra el autor del script cuando es invocado
__author__ = "Ing. Roldan Vargas (rvargas at cenditel.gob.ve)"
## Muestra documentación breve sobre el script
__doc__    = "Modelo de datos para el registro y autenticación de usuarios con privilegios para acceder al sistema"

from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from apps.usuario.functions import generar_password

class Institucion(models.Model):
    """!
    Clase que gestiona los datos de las instituciones de las cuales se pueden registrar los usuarios

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) Nodo Mérida - Venezuela
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 04-05-2015
    @version 3.0.0
    """
    nombre = models.CharField(max_length=100, unique=True)
    descripcion = models.CharField(max_length=255, unique=True)

    def __str__(self):
        return self.nombre

    def __unicode__(self):
        return self.nombre

    class Meta:
        """!
        Metaclase que permite establecer las propiedades de la clase Institucion

        @author Ing. Roldan Vargas rvargas at cenditel.gob.ve
        @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) Nodo Mérida - Venezuela
        @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
        @date 04-05-2015
        @version 3.0.0
        """
        ordering = ["nombre"]
        verbose_name = _(u"Institución")
        verbose_name_plural = _(u"Instituciones")

class Cargo(models.Model):
    """!
    Clase que gestiona los datos sobre los cargos de los usuarios dentro de una institución

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) Nodo Mérida - Venezuela
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 04-05-2015
    @version 3.0.0
    """
    nombre = models.CharField(max_length=75, unique=True)

    def __str__(self):
        return self.nombre

    def __unicode__(self):
        return self.nombre

    class Meta:
        """!
        Metaclase que permite establecer las propiedades de la clase Cargo

        @author Ing. Roldan Vargas rvargas at cenditel.gob.ve
        @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) Nodo Mérida - Venezuela
        @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
        @date 04-05-2015
        @version 3.0.0
        """
        ordering = ["nombre"]
        verbose_name = _(u"Cargo")
        verbose_name_plural = _(u"Cargos")

class UserProfile(models.Model):
    """!
    Clase que gestiona los datos de los analistas que tendrán acceso al sistema

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) Nodo Mérida - Venezuela
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 04-05-2015
    @version 3.0.0
    """
    institucion = models.ForeignKey(Institucion, help_text=_(u"Institución a la que pertenece el usuario"))
    cargo = models.ForeignKey(Cargo, help_text=_(u"Cargo que posee el usuario dentro de la institución"))
    fecha_modpass = models.DateTimeField(null=True, help_text=_(u"Fecha en la que se modificó por última vez la "
                                                                u"contraseña del usuario"))
    user = models.OneToOneField(User, related_name="profile",
                                help_text=_(u"Relación entre los datos de registro del analista y "
                                            u"el usuario de acceso al sistema"))

    def __str__(self):
        return "%s, %s" % (self.user.first_name, self.user.last_name)

    def __unicode__(self):
        return "%s, %s" % (self.user.first_name, self.user.last_name)

    class Meta:
        """!
        Metaclase que permite establecer las propiedades de la clase Analista

        @author Ing. Roldan Vargas rvargas at cenditel.gob.ve
        @author Centro Nacional de Desarrollo e Investigación en Tecnologías Libres (CENDITEL) Nodo Mérida - Venezuela
        @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
        @date 04-05-2015
        @version 3.0.0
        """
        ordering = ["institucion"]
        verbose_name = _(u"Analista")
        verbose_name_plural = _(u"Analistas")